@@ -27,7 +27,7 @@
 import json
 import urlparse
 
-from .state import env
+from .state import env, app_uri, service_uri
 from .base import HttpBaseHandler
 from .exceptions import HttpReturnError
 
@@ -61,14 +61,10 @@ class ActionHandler(HttpBaseHandler):
         self.options = options
 
     def uri(self):
-        uri = "%s/%s/%s/%s/%s" % (
-                env.base_uri.strip('/'),
-                env.api_version.strip('/'),
-                env.account.strip('/'),
-                env.label.strip('/'),
-                env.resource.strip('/')
-                )
-        return uri
+        if env.service:
+            return service_uri(service=env.service)
+        else:
+            return app_uri(appname=env.appname)
 
     def queue(self):
         """Queue the action on the server."""
