@@ -69,7 +69,7 @@ class HttpBaseHandler(object):
 
         if response.status_code in bad_statuses:
             error = json.loads(response.content)
-            raise HttpReturnError(response.status_code, error['error'])
+            raise HttpReturnError(response.status_code, error['message'])
 
         error_statuses = [500, 501, 502, 503, 504]
 
