@@ -68,42 +68,89 @@ env = _AttributeDict({
     'base_uri': 'https://api.30loops.net',
     'api_version': '0.9',
     'account': None,
-    'label': None,
-    'resource': None,
+    'service': None,
+    'appname': None,
     'username': None,
     'password': None
 })
 
 
-def resource_uri(
+def uri(
         base_uri=None,
         api_version=None,
-        account=None,
-        label=None,
-        resource=None):
-    """Return the URI of a resource as a string."""
+        account=None):
+    """Compose the base uri."""
     if not base_uri:
         base_uri = env.base_uri
     if not api_version:
         api_version = env.api_version
     if not account:
         account = env.account
-    if not label:
-        label = env.label
-    if not resource:
-        resource = env.resource
     path = []
     path.append(api_version.strip('/'))
-    path.append(account.strip('/'))
-    path.append(label.strip('/'))
-    if not isinstance(resource, type(None)):
-        path.append(resource.strip('/'))
+    if not isinstance(account, type(None)):
+        path.append(account.strip('/'))
 
     return "%s/%s" % (base_uri.strip('/'), '/'.join(path))
 
-def construct_resource_uri(**kwargs):
-    #FIXME: Deprecated. Marked for removal.
-    return resource_uri(**kwargs)
+
+def app_uri(
+        base_uri=None,
+        api_version=None,
+        account=None,
+        appname=None):
+    """Compose the app uri."""
+    if not appname:
+        appname = env.appname
+
+    return "%s/apps/%s" % (uri(base_uri, api_version, account), appname)
+
+
+def service_uri(
+        base_uri=None,
+        api_version=None,
+        account=None,
+        appname=None,
+        service=None):
+    """Compose as service uri."""
+    if not service:
+        service = env.service
+
+    return "%s/services/%s" % (app_uri(base_uri, api_version, account, appname),
+            service)
+
+
+# def resource_uri(
+#         base_uri=None,
+#         api_version=None,
+#         account=None,
+#         label=None,
+#         resource=None):
+#     """Return the URI of a resource as a string."""
+#     if not base_uri:
+#         base_uri = env.base_uri
+#     if not api_version:
+#         api_version = env.api_version
+#     if not account:
+#         account = env.account
+#     if not label:
+#         label = env.label
+#     if not resource:
+#         resource = env.resource
+#     path = []
+#     path.append(api_version.strip('/'))
+#     path.append(account.strip('/'))
+#     path.append(label.strip('/'))
+#     if not isinstance(resource, type(None)):
+#         path.append(resource.strip('/'))
+
+#     return "%s/%s" % (base_uri.strip('/'), '/'.join(path))
+
+
+# def construct_resource_uri(**kwargs):
+#     #FIXME: Deprecated. Marked for removal.
+#     return resource_uri(**kwargs)
+
 
 def resource_collection_uri(
         base_uri=None,
