@@ -1,16 +1,15 @@
 from docar.exceptions import ValidationError
+import re
 
 
 def naming(value):
-    import re
     p = re.compile('^[a-z0-9_]+$')
     if not p.match(value):
         raise ValidationError("String invalid. May contain [a-z0-9_].")
 
 
 def naming_with_dashes(value):
-    import re
-    p = re.compile('^[a-z0-9_-]+$')
+    p = re.compile('^[A-Za-z0-9_-]+$')
     if not p.match(value):
         raise ValidationError("String invalid. May contain [a-z0-9_-].")
 
